#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hasql-notifications
version:              0.2.0.5
visibility:           public
id:                   hasql-notifications-0.2.0.5-GFiLqvJsKrFJDapFfSA62m
key:                  hasql-notifications-0.2.0.5-GFiLqvJsKrFJDapFfSA62m
license:              BSD-3-Clause
copyright:            2020 Diogo Biazus
maintainer:           diogo@biazus.ca
author:               Diogo Biazus
homepage:             https://github.com/diogob/hasql-notifications
synopsis:             LISTEN/NOTIFY support for Hasql
description:
    Use PostgreSQL Asynchronous notification support with your Hasql Types.

category:             Hasql, Database, PostgreSQL
abi:                  ee1c8feb72c785698bb9e996fa267dfb
exposed:              True
exposed-modules:      Hasql.Notifications
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hasql-notifications-0.2.0.5
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hasql-notifications-0.2.0.5
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hasql-notifications-0.2.0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hasql-notifications
hs-libraries:         HShasql-notifications-0.2.0.5-GFiLqvJsKrFJDapFfSA62m
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    hasql-1.6.1.1-5EAK4DCqBKMAQSILbwqOlf
    hasql-pool-0.8.0.2-28HMX9ffkiQ49F5z8lZdqX
    postgresql-libpq-0.9.5.0-6Abcvnlrbx38D8lE6uFyjU text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-hasql-notifications/html/hasql-notifications.haddock

haddock-html:         /usr/share/doc/haskell-hasql-notifications/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

